###############################################################################
# AwardSettings.pm                                                            #
###############################################################################
# Member Awards Admin                                                         #
# Author: Derek Barnstorm                                                     #
# Updated to 2.7.00 by Deborah Rorabaugh (Dandello)                           #
###############################################################################
# YaBB: Yet another Bulletin Board                                            #
# Open-Source Community Software for Webmasters                               #
# Version:        YaBB 2.7.00                                                 #
# Distributed by: http://www.yabbforum.com                                    #
# =========================================================================== #
# Copyright (c) 2000-2017 YaBB (www.yabbforum.com) - All Rights Reserved.     #
# Software by:  The YaBB Development Team                                     #
#               with assistance from the YaBB community.                      #
###############################################################################
use strict;
no strict qw(refs);
use warnings;
our $VERSION            = '2.7.00';
our $awardsettingspmver = 'YaBB 2.7.00 $Revision: 0.4 $';

our ($action);
$action ||= q{};
if ( $action eq 'detailedversion' ) { return 1; }

our (
    $action_area,  $adminurl,      $awards_imsubject, $awards_imtext,
    $awards_name,  $en_awards,     $en_awards_gmod,   $en_awards_im,
    $en_awards_mv, $en_awards_tab, $imagesdir,        $modimgurl,
    $vardir,       $yymain,        $yysetlocation,    $yytitle,
    %admin_txt,    %award_txt,     %FORM,             %INFO,
    %mod_list,     %lngs,          $langdir,
);

load_language('Mods/Awards');
load_language('Admin');

sub Awards {
    is_admin_or_gmod();
    $yymain = qq~
<form action="$adminurl?action=awards2" method="post">
    <div class="bordercolor rightboxdiv">
        <table class="border-space pad-cell" style="margin-bottom: .5em;">
        <colgroup>
            <col width="50%" />
            <col width="50%" />
        </colgroup>
        <tr>
            <th style="text-align: left;" class="titlebg" colspan="2"><img src="$imagesdir/profile.gif" alt="" /> $award_txt{'30'}</th>
        </tr><tr>
            <td class="windowbg2"><label for="en_awards">$award_txt{'21'}</label></td>
            <td class="windowbg2"><input type="checkbox" name="en_awards" id="en_awards" value="1"${ischecked($en_awards)} /></td>
        </tr><tr>
            <td class="windowbg2"><label for="en_awards_gmod">$award_txt{'22'}</label></td>
            <td class="windowbg2"><input type="checkbox" name="en_awards_gmod" id="en_awards_gmod" value="1"${ischecked($en_awards_gmod)} /></td>
        </tr><tr>
            <td class="windowbg2"><label for="en_awards_tab">$award_txt{'23'}</label></td>
            <td class="windowbg2"><input type="checkbox" name="en_awards_tab" id="en_awards_tab" value="1"${ischecked($en_awards_tab)} /></td>
        </tr><tr>
            <td class="windowbg2"><label for="en_awards_mv">$award_txt{'24'}</label></td>
            <td class="windowbg2"><input type="checkbox" name="en_awards_mv" id="en_awards_mv" value="1"${ischecked($en_awards_mv)} /></td>
        </tr><tr>
            <td class="windowbg2"><label for="en_awards_im">$award_txt{'41'}</label></td>
            <td class="windowbg2"><input type="checkbox" name="en_awards_im" id="en_awards_im" value="1"${ischecked($en_awards_im)} /></td>
        </tr>
        </table>
    </div>
    <div class="bordercolor rightboxdiv">
        <table class="border-space pad-cell" style="margin-bottom: .5em;">
            <tr>
                <th class="titlebg"><img src="$imagesdir/preferences.gif" alt="" /> $admin_txt{'10'}</th>
            </tr><tr>
                <td class="catbg center">
                    <input class="button" type="submit" value="$admin_txt{'10'}" />
                </td>
            </tr>
        </table>
    </div>
</form>
~;
    my $show_awards = q{};
    our (%awards);
    for my $lng ( sort keys %lngs ) {
        if ( -e "$langdir/$lng/Mods/Awards_set.lng" ) {
            require "$langdir/$lng/Mods/Awards_set.lng";
        }
        else { require "$langdir/English/Mods/Awards_set.lng" }
        $awards{'name'}      ||= $award_txt{'39'};
        $awards{'imsubject'} ||= $award_txt{'44'};
        $awards{'imtext'}    ||= $award_txt{'45'};
        $awards{'imtext'} =~ s/<br\s \/>/\n/gxsm;

        our (%award_list);
        if ( -e "$langdir/$lng/Mods/Awards.txt" ) {
            require "$langdir/$lng/Mods/Awards.txt";
        }
        else { require "$langdir/English/Mods/Awards.txt"; }

        my $total_awards = scalar keys %award_list || 0;
        my $show_awards_l = qq~<div class="bordercolor rightboxdiv">
    <table class="border-space pad-cell" style="margin-bottom: .5em;">
        <tr>
            <th class="titlebg" style="text-align: left;" colspan="6"><img src="$imagesdir/profile.gif" border="0" alt="" style="vertical-align: middle;" /> $award_txt{'31'} ($total_awards) - $lngs{$lng}</th>
        </tr>~;
        if ($total_awards > 0) {
            $show_awards_l .= qq~
<tr class="catbg" style="font-weight: bold; font-size: 11px;">
    <td>$award_txt{'26'}</td>
    <td>$award_txt{'02'}</td>
    <td>$award_txt{'01'}</td>
    <td>$award_txt{'07'}</td>
    <td>$award_txt{'27'}</td>
    <td>$award_txt{'06'}</td>
</tr>~;

            my %sorted = ();
            foreach my $id (keys %award_list) {
                $sorted{$id} = ${$award_list{$id}}[0];
            }
            my @sorted = sort { $sorted{$a} <=> $sorted{$b} } keys %sorted;
            foreach my $id (@sorted) {
                $show_awards_l .= qq~
<tr class="windowbg2">
    <td>$id</td>
    <td>${$award_list{$id}}[1]</td>
    <td><img src="$modimgurl/Awards/${$award_list{$id}}[2]" alt="${$award_list{$id}}[2]" title="${$award_list{$id}}[2]" /></td>
    <td>${$award_list{$id}}[3]</td>
    <td>${$award_list{$id}}[0]</td>
    <td>[<a href="$adminurl?action=awards_edit;id=$id;lang=$lng">$award_txt{'19'}</a>]&nbsp;[<a href="$adminurl?action=awards_delete;id=$id;lang=$lng" onclick="return confirm('$award_txt{'17'}\\n\\n$award_txt{'28'}');">$award_txt{'18'}</a>]</td>
</tr>~;
            }
        }
        else {
            $show_awards_l .= qq~
<tr class="windowbg2">
    <td>$award_txt{'29'}</td>
</tr>~;
        }
        if ($en_awards_im && $en_awards_im != 0) {
            $yymain .= qq~
<form action="$adminurl?action=awards3" method="post">
    <div class="bordercolor rightboxdiv"><table class="border-space pad-cell" style="margin-bottom: .5em;">
        <colgroup>
            <col width="50%" />
            <col width="50%" />
        </colgroup>
        <tr>
            <th style="text-align: left;" class="titlebg" colspan="2"><img src="$imagesdir/profile.gif" alt="" /> $award_txt{'30b'} - $lngs{$lng}</th>
        </tr><tr>
            <td class="windowbg2"><label for="awards_name">$award_txt{'25'}:</label></td>
            <td class="windowbg2"><input type="text" size="35" name="awards_name" id="awards_name" value="$awards{'name'}" /></td>
        </tr><tr>
            <td class="windowbg2"><label for="awards_imsubject">$award_txt{'42'}:</label></td>
            <td class="windowbg2"><input type="text" size="35" name="awards_imsubject" id="awards_imsubject" value="$awards{'imsubject'}" /></td>
        </tr><tr>
            <td class="windowbg2"><label for="awards_imtext">$award_txt{'43'}:<br /><span class="small">$award_txt{'46'}:<br />{name} - $award_txt{'47'}<br />{award} - $award_txt{'48'}<br />{reason} - $award_txt{'49'}<br />{myname} - $award_txt{'50'}<br />{mbname} - $award_txt{'51'}</span></label></td>
            <td class="windowbg2"><textarea name="awards_imtext" id="awards_imtext" cols="35" rows="7">$awards{'imtext'}</textarea></td>
        </tr>
        </table>
    </div>
    <div class="bordercolor rightboxdiv">
        <table class="border-space pad-cell" style="margin-bottom: .5em;">
            <tr>
                <th class="titlebg"><img src="$imagesdir/preferences.gif" alt="" /> $admin_txt{'10'}</th>
            </tr><tr>
                <td class="catbg center">
                    <input type="hidden" id="lang" name="lang" value="$lng" />
                    <input class="button" type="submit" value="$admin_txt{'10'}" />
                </td>
            </tr>
        </table>
    </div>
</form>
~;
        }
        $yymain .= $show_awards_l;
    }
    $yymain .= qq~<form action="$adminurl?action=awards_add" method="post">
    <div class="bordercolor rightboxdiv">
        <table class="border-space pad-cell" style="margin-bottom: .5em;">
        <colgroup>
            <col width="25%" />
            <col width="75%" />
        </colgroup>
        <tr>
        <th class="titlebg" style="text-align: left;" colspan="2"><img src="$imagesdir/profile.gif" alt="" /> $award_txt{'32'}</th>
        </tr><tr>
            <td  class="windowbg2"><label for="award_id"><span style="font-weight: bold;">$award_txt{'26'}:</span><br /><span class="small">$award_txt{'33'}</span></label></td>
            <td  class="windowbg2"><input type="text" name="award_id" id="award_id" size="35" /></td>
        </tr><tr>
            <td  class="windowbg2"><label for="award_title"><span style="font-weight: bold;">$award_txt{'02'}:</span><br /><span class="small">$award_txt{'34'}</span></label></td>
            <td  class="windowbg2"><input type="text" name="award_title" id="award_title" size="35" /></td>
        </tr><tr>
            <td  class="windowbg2"><label for="award_image"><span style="font-weight: bold;">$award_txt{'01'}:</span><br /><span class="small">$award_txt{'35'}</span></label></td>
            <td  class="windowbg2"><input type="text" name="award_image" id="award_image" size="35" /></td>
        </tr><tr>
            <td  class="windowbg2"><label for="award_desc"><span style="font-weight: bold;">$award_txt{'07'}:</span><br /><span class="small">$award_txt{'36'}</span></label></td>
            <td  class="windowbg2"><input type="text" name="award_desc" id="award_desc" size="70" /></td>
        </tr><tr>
            <td  class="windowbg2"><label for="award_order"><span style="font-weight: bold;">$award_txt{'27'}:</span><br /><span class="small">$award_txt{'37'}</span></label></td>
            <td  class="windowbg2"><input type="text" name="award_order" id="award_order" size="3" /></td>
        </tr>
    </table>
</div>
<div class="bordercolor rightboxdiv">
    <table class="border-space pad-cell" style="margin-bottom: .5em;">
        <tr>
            <th class="titlebg"><img src="$imagesdir/preferences.gif" alt="" /> $admin_txt{'10'}</th>
        </tr><tr>
            <td class="catbg center"><input class="button" type="submit" value="$award_txt{'38'}" /></td>
        </tr>
    </table>
</div>
</form>
~;

    $yytitle     = $mod_list{'awards1'};
    $action_area = 'awards';
    admintemplate();
    exit;
}

sub Awards2 {
    is_admin_or_gmod();

    $en_awards        = $FORM{'en_awards'}        || '0';
    $en_awards_gmod   = $FORM{'en_awards_gmod'}   || '0';
    $en_awards_tab    = $FORM{'en_awards_tab'}    || '0';
    $en_awards_mv     = $FORM{'en_awards_mv'}     || '0';
    $en_awards_im     = $FORM{'en_awards_im'}     || '0';

    require Admin::NewSettings;
    save_settings_to('Settings.pm');

    if ( $action eq 'awards2' ) {
        $yysetlocation = qq~$adminurl?action=awards~;
        redirectexit();
    }
    return;
}

sub Awards3 {
    is_admin_or_gmod();

    $awards_name = $FORM{'name'} || q{};
    $awards_imsubject = $FORM{'awards_imsubject'} || q{};
    $awards_imtext    = $FORM{'awards_imtext'}    || q{};
    $awards_imtext =~ s/\r(?=\n*)//gxsm;
    $awards_imtext =~ s~\n~<br />~gxsm;
    my $lang = $FORM{'lang'};

    my $setfile = <<"EOF";
\%awards = (
'name' => q~$awards_name~,
'imsubject' => q~$awards_imsubject~,
'imtext' => q~$awards_imtext~,
);

1;
EOF
    our ($FILE);
    fopen( 'FILE', '>', "Languages/$lang/Mods/Awards_set.lng" );
    print {$FILE} $setfile;
    fclose('FILE');

    if ( $action eq 'awards3' ) {
        $yysetlocation = qq~$adminurl?action=awards~;
        redirectexit();
    }
    return;
}

sub AddAward {
    is_admin_or_gmod();

    my $award_id    = $FORM{'award_id'};
    my $award_title = $FORM{'award_title'};
    my $award_image = $FORM{'award_image'};
    my $award_desc  = $FORM{'award_desc'};
    my $award_order = $FORM{'award_order'};

    if ( $award_id eq q{} ) { fatal_error( 'no_value', "$award_txt{'26'}" ); }
    if ( $award_title eq q{} ) {
        fatal_error( 'no_value', "$award_txt{'02'}" );
    }
    if ( $award_image eq q{} ) {
        fatal_error( 'no_value', "$award_txt{'01'}" );
    }
    if ( $award_desc eq q{} ) { fatal_error( 'no_value', "$award_txt{'07'}" ); }
    if ( $award_order eq q{} ) {
        fatal_error( 'no_value', "$award_txt{'27'}" );
    }

    foreach my $lang (keys %lngs) {
        our (%award_list);
        if (-e "$langdir/$lang/Mods/Awards.txt" ) {
            require "$langdir/$lang/Mods/Awards.txt";
            my @award = ();
#[50, 'Best Content', 'GoldShield2.png', q~This Award is issued to Members with the best content.~],
            $award_list{$award_id} = [$award_order, $award_title, $award_image, $award_desc];
            foreach my $key ( keys %award_list ) {
                my $line =  qq~'$key' => \[${$award_list{$key}}[0], '${$award_list{$key}}[1]', '${$award_list{$key}}[2]', q\~${$award_list{$key}}[3]\~\],\n~;
                push @award, $line;
            }
            our ($AWARDS);
            my $award = q~%award_list = (
~;
            $award .= join q{}, @award;
            $award .= q~);

1;
~;

            fopen( 'AWARDS', '>', "$langdir/$lang/Mods/Awards.txt" )
                || fatal_error( 'cannot_open', "$langdir/$lang/Mods/Awards.txt", 1 );
            print {$AWARDS} $award;
            fclose('AWARDS');
        }
    }


    if ( $action eq 'awards_add' ) {
        $yysetlocation = qq~$adminurl?action=awards~;
        redirectexit();
    }
    return;
}

sub DeleteAward {
    is_admin_or_gmod();
    my $id = $INFO{'id'};
    foreach my $lang (keys %lngs) {
        our (%award_list);
        if (-e "$langdir/$lang/Mods/Awards.txt" ) {
            require "$langdir/$lang/Mods/Awards.txt";
            delete $award_list{$id};
            my @award = ();
            foreach my $key ( keys %award_list ) {
                my $line =  qq~'$key' => \[${$award_list{$key}}[0], '${$award_list{$key}}[1]', '${$award_list{$key}}[2]', q\~${$award_list{$key}}[3]\~\],\n~;
                push @award, $line;
            }
            our ($AWARDS);
            my $award = q~%award_list = (
~;
            $award .= join q{}, @award;
            $award .= q~);

1;
~;

            fopen( 'AWARDS', '>', "$langdir/$lang/Mods/Awards.txt" )
                || fatal_error( 'cannot_open', "$langdir/$lang/Mods/Awards.txt", 1 );
            print {$AWARDS} $award;
            fclose('AWARDS');
        }
    }

    if ( $action eq 'awards_delete' ) {
        $yysetlocation = qq~$adminurl?action=awards~;
        redirectexit();
    }
    return;
}

sub EditAward {
    is_admin_or_gmod();

    my $id         = $INFO{'id'};
    my $award_edit = q{};
    my $lng = $INFO{'lang'};

    our (%award_list);
    if (-e "$langdir/$lng/Mods/Awards.txt" ) {
        require "$langdir/$lng/Mods/Awards.txt";
    }
    else { require "$langdir/English/Mods/Awards.txt";}

    $yymain = qq~
<form action="$adminurl?action=awards_edit2" method="post">
<div class="bordercolor rightboxdiv">
    <table class="border-space pad-cell" style="margin-bottom: .5em;">
        <colgroup>
            <col width="25%" />
            <col width="75%" />
        </colgroup>
        <tr>
            <th class="titlebg" colspan="2"><img src="$imagesdir/profile.gif" /> $award_txt{'40'} - $lngs{$lng}</th>
        </tr><tr>
            <td class="windowbg2"><label for="award_id"><span style="font-weight: bold;">$award_txt{'26'}:</span></label></td>
            <td class="windowbg2"><input type="hidden" name="award_id" id="award_id" value="$id" />$id</td>
        </tr><tr>
            <td class="windowbg2"><label for="award_title"><span style="font-weight: bold;">$award_txt{'02'}:</span><br /><span class="small">$award_txt{'34'}</span></label></td>
            <td class="windowbg2"><input type="text" name="award_title" id="award_title" size="35" value="${$award_list{$id}}[1]" /></td>
        </tr><tr>
            <td class="windowbg2"><label for="award_image"><span style="font-weight: bold;">$award_txt{'01'}:</span><br /><span class="small">$award_txt{'35'}</span></label></td>
            <td class="windowbg2"><input type="text" name="award_image" id="award_image" size="35" value="${$award_list{$id}}[2]" /></td>
        </tr><tr>
            <td class="windowbg2"><label for="award_desc"><span style="font-weight: bold;">$award_txt{'07'}:</span><br /><span class="small">$award_txt{'36'}</span></label></td>
            <td class="windowbg2"><input type="text" name="award_desc" id="award_desc" size="70" value="${$award_list{$id}}[3]" /></td>
        </tr><tr>
            <td class="windowbg2"><label for="award_order"><span style="font-weight: bold;">$award_txt{'27'}:</span><br /><span class="small">$award_txt{'37'}</span></label></td>
            <td class="windowbg2"><input type="text" name="award_order" id="award_order" size="3" value="${$award_list{$id}}[0]" /></td>
        </tr>
    </table>
</div>
<div class="bordercolor rightboxdiv">
    <table class="border-space pad-cell" style="margin-bottom: .5em;">
        <tr>
            <th class="titlebg"><img src="$imagesdir/preferences.gif" alt="" /> $admin_txt{'10'}</th>
        </tr><tr>
            <td class="catbg center">
                <input type="hidden" id="lang" name="lang" value="$lng" />
                <input class="button" type="submit" value="$admin_txt{'10'}" />&nbsp;<input type="button" class="button" value="$award_txt{'12'}" onclick="location.href='$adminurl?action=awards';" />
            </td>
        </tr>
    </table>
</div>
</form>~;

    $yytitle = $mod_list{'awards1'};
    admintemplate();
    exit;

}

sub EditAward2 {
    is_admin_or_gmod();

    my $award_id    = $FORM{'award_id'};
    my $award_title = $FORM{'award_title'};
    my $award_image = $FORM{'award_image'};
    my $award_desc  = $FORM{'award_desc'};
    my $award_order = $FORM{'award_order'};
    my $lang        = $FORM{'lang'};

    if ( $award_title eq q{} ) {
        fatal_error( 'no_value', "$award_txt{'02'}" );
    }
    if ( $award_image eq q{} ) {
        fatal_error( 'no_value', "$award_txt{'01'}" );
    }
    if ( $award_desc eq q{} ) { fatal_error( 'no_value', "$award_txt{'07'}" ); }
    if ( $award_order eq q{} ) {
        fatal_error( 'no_value', "$award_txt{'27'}" );
    }

    our (%award_list);
    if (-e "$langdir/$lang/Mods/Awards.txt" ) {
        require "$langdir/$lang/Mods/Awards.txt";
    }
    else { require "$langdir/English/Mods/Awards.txt";}

    my @award = ();
    foreach my $key ( keys %award_list ) {
        if ($key eq $award_id ) {
            my $line =  qq~'$key' => \[ $award_order, '$award_title', '$award_image', q\~$award_desc\~\],\n~;
            push @award, $line;
        }
        else {
            my $line =  qq~'$key' => \[${$award_list{$key}}[0], '${$award_list{$key}}[1]', '${$award_list{$key}}[2]', q\~${$award_list{$key}}[3]\~\],\n~;
            push @award, $line;
        }
    }
    our ($AWARDS);
    my $award = q~%award_list = (
~;
    $award .= join q{}, @award;
    $award .= q~);

1;
~;

    fopen( 'AWARDS', '>', "$langdir/$lang/Mods/Awards.txt" )
      || fatal_error( 'cannot_open', "$langdir/$lang/Mods/Awards.txt", 1 );
    print {$AWARDS} "$award";
    fclose('AWARDS');

    if ( $action eq 'awards_edit2' ) {
        $yysetlocation = qq~$adminurl?action=awards~;
        redirectexit();
    }
    return;
}

1;
