###############################################################################
# Awards.pm                                                                   #
###############################################################################
# Member Awards                                                               #
# Author: Derek Barnstorm                                                     #
# Updated to 2.7.00 by Deborah Rorabaugh (Dandello)                           #
###############################################################################
# YaBB: Yet another Bulletin Board                                            #
# Open-Source Community Software for Webmasters                               #
# Version:        YaBB 2.7.00                                                 #
# Distributed by: http://www.yabbforum.com                                    #
# =========================================================================== #
# Copyright (c) 2000-2017 YaBB (www.yabbforum.com) - All Rights Reserved.     #
# Software by:  The YaBB Development Team                                     #
#               with assistance from the YaBB community.                      #
###############################################################################
use strict;
no strict qw(refs);

#use warnings;
our $VERSION = '2.7.00';

our $awardspmver = 'YaBB 2.7.00 $Revision: 0.3 $';
our ($action);
$action ||= q{};
if ( $action eq 'detailedversion' ) { return 1; }

our (
    $award_title,     $awards_admin,      $awards_imsubject,
    $awards_imtext,   $awards_name,       $date,
    $en_awards,       $en_awards_gmod,    $en_awards_im,
    $iamadmin,        $iamgmod,           $mbname,
    $memberdir,       $messageid,         $modimgurl,
    $scripturl,       $tem_all_awards,    $tem_award_edit,
    $tem_award_page,  $tem_award_row,     $tem_awards,
    $tem_awards_2,    $tem_awardsname,    $tem_row_award_2,
    $tem_show_awards, $uid,               $user,
    $user_award_date, $user_award_reason, $user_award_who,
    $username,        $vardir,            $yymain,
    $yynavigation,    $yysetlocation,     $yytitle, $do_scramble_id,
    %FORM,            %INFO,              %link,
    %useraccount,
);
our (%award_list, %award_txt);
my $lang = what_language();
if ( -e ("Languages/$lang/Mods/Awards.txt") ) {
    require "Languages/$lang/Mods/Awards.txt";
}
else {require "Languages/English/Mods/Awards.txt";}
if ( !$en_awards ) { fatal_error('not_allowed'); }

load_language('Mods/Awards');
get_template('Mods/Awards');

sub Awards {
    my $total_awards = scalar keys %award_list || 0;
    our (%awards);
    load_language('Mods/Awards_set');
    $awards{'name'}      ||= $award_txt{'39'};
    $yytitle = $awards{'name'};

    my $show_awards = q{};
    my $award_row   = q{};
    if ($total_awards) {
        if ( $INFO{'id'} ) {
            my $id = $INFO{'id'};
            if ($award_list{$id}) {
                my ( undef, $award_title, $award_image, $award_desc ) = @{$award_list{$id}};
                $award_image ||= q{};
                $award_title ||= q{};
                $award_desc  ||= q{};
                $show_awards = $tem_show_awards;
                $show_awards =~
                  s/\Q{yabb awardimg}\E/$modimgurl\/Awards\/$award_image/gxsm;
                $show_awards =~ s/\Q{yabb award_title}\E/$award_title/gxsm;
                $show_awards =~ s/\Q{yabb awarddesc}\E/$award_desc/gxsm;
                if ( $award_title ne q{} ) {
                    $yytitle .= qq~ - $award_title~;
                }
                $yymain = $tem_awards;
                $yymain =~ s/\Q{yabb id}\E/$award_title/gxsm;
                $yymain =~ s/\Q{yabb award_title}\E/$award_title/gxsm;
            }
        }
        elsif ( $INFO{'username'} ) {
            $user = $INFO{'username'};
            if ($do_scramble_id) { decloak($user); }
            if ( !load_user($user) ) { fatal_error('no_profile_exists'); }
            $yytitle .= qq~ - ${ $uid . $user }{'realname'}~;
            if ( -e "$memberdir/$user.awards" ) {
                our ($UAWARDS);
                fopen( 'UAWARDS', '<', "$memberdir/$user.awards" );
                my @getawards = <$UAWARDS>;
                fclose('UAWARDS');
                foreach my $user_award ( sort { $b cmp $a } @getawards ) {
                    chomp $user_award;
                    my (
                        $user_award_date,   $user_award_id,
                        $user_award_reason, $user_award_who
                    ) = split /[|]/xsm, $user_award;
                    load_user($user_award_who);
                    my $who_name = $link{$user_award_who};
                    $user_award_date ||= time;
                    $user_award_date = timeformat($user_award_date);
                    my ( undef, $award_title, $award_image, $award_desc ) = @{$award_list{$user_award_id}};
                    if ( $user_award_id ) {
                        $award_row .= $tem_row_award_2;
                        $award_row =~ s/{user_award_id}/$user_award_id/gxsm;
                        $award_row =~ s/{award_title}/$award_title/gxsm;
                        $award_row =~ s/{user_award_reason}/$user_award_reason/gxsm;
                        $award_row =~ s/{user_award_date}/$user_award_date/gxsm;
                        $award_row =~ s/{who_name}/$who_name/gxsm;
                        $award_row =~ s/{awards_admin}/$awards_admin/gxsm;
                        $award_row =~ s/\Q{yabb awardimg}\E/$modimgurl\/Awards\/$award_image/gxsm;
                    }
                }
            }
            $yymain = $tem_awards_2;
            $yymain =~ s/\Q{yabb id}\E/${ $uid . $user }{'realname'}/gxsm;
        }
        else {
            my %sorted = ();
            foreach my $id (keys %award_list) {
                $sorted{$id} = ${$award_list{$id}}[0];
            }
            my @sorted = sort { $sorted{$a} <=> $sorted{$b} } keys %sorted;
            foreach my $id (@sorted) {
                my ( $award_id, $award_title, $award_image, $award_desc ) = @{$award_list{$id}};
                $award_row .= $tem_award_row;
                $award_row =~ s/{award_id}/$id/gxsm;
                $award_row =~ s/{award_title}/${$award_list{$id}}[1]/gxsm;
                $award_row =~ s/\Q{yabb awarddesc}\E/${$award_list{$id}}[3]/gxsm;
                $award_row =~
                  s/\Q{yabb awardimg}\E/$modimgurl\/Awards\/${$award_list{$id}}[2]/gxsm;
            }
            $yymain = $tem_all_awards;
        }
    }
    else {
        $yymain = $tem_awardsname;
    }
    $award_title ||= q{};
    $yymain =~ s/\Q{yabb award_title}\E/$award_title/gxsm;
    $yymain =~ s/{total_awards}/$total_awards/gxsm;
    $yymain =~ s/\Q{yabb award_row}\E/$award_row/gxsm;
    $yymain =~ s/\Q{yabb awardtitle}\E/$award_title/gxsm;
    $yymain =~ s/\Q{yabb show_awards}\E/$show_awards/gxsm;
    $yymain =~ s/\Q{yabb awards_name}\E/$awards{'name'}/gxsm;

    $yynavigation = qq~&rsaquo; $awards{'name'}~;
    template();

}

sub AwardMember {

    if ( !$iamadmin && ( !$iamgmod || !$en_awards_gmod ) ) {
        fatal_error('not_allowed');
    }

    $user = $INFO{'username'};
    if ( !load_user($user) ) { fatal_error('no_profile_exists'); }
    our (%awards);
    load_language('Mods/Awards_set');
    $awards{'name'}      ||= $award_txt{'39'};

    my $show_awards = q{};
    for my $award (keys %award_list) {
        my ( undef, $award_title, $award_image, $award_desc ) = @{$award_list{$award}};
        $show_awards .= qq~<option value="$award">$award_title</option>\n~;
    }

    $yymain .= $tem_award_page;
    $yymain =~ s/\Q{yabb awards_name}\E/$awards{'name'}/gxsm;
    $yymain =~ s/\Q{yabb username}\E/$user/gxsm;
    {
        no strict qw(refs);
        $yymain =~ s/\Q{yabb id}\E/${ $uid . $user }{'realname'}/gxsm;
    }
    $yymain =~ s/\Q{yabb show_awards}\E/$show_awards/gxsm;
    {
        no strict qw(refs);
        $yytitle = "$awards_name - ${ $uid . $user}{'realname'}";
    }
    $yynavigation = qq~&rsaquo; $awards_name~;
    template();
}

sub AwardMember2 {

    if ( !$iamadmin && ( !$iamgmod || !$en_awards_gmod ) ) {
        fatal_error('not_allowed');
    }

    $user = $FORM{'username'};
    if ( !load_user($user) ) { fatal_error('no_profile_exists'); }

    my $award_id     = $FORM{'award'};
    my $award_reason = $FORM{'award_reason'};

    if ( !$FORM{'award'} )        { fatal_error('no_award'); }
    if ( !$FORM{'award_reason'} ) { fatal_error('no_award_reason'); }

    our ($AWARDS);
    fopen( 'AWARDS', '>>', "$memberdir/$user.awards" );
    print {$AWARDS} "$date|$award_id|$award_reason|$username\n";
    fclose('AWARDS');

    if ($en_awards_im) {
        our (%award_list);
        require "Languages/English/Mods/Awards.txt";
        our (%awards);
        load_language('Mods/Awards_set');
        for my $award (keys %award_list) {
            if ( $award =~ /\b$award_id\b/ ) {
                $award_title = ${$award_list{$award}}[1];
            }
        }
        require Sources::MyCenter;
        $messageid = getnewid();
        my $awardmess = "$messageid|$username|$user|||$awards{'imsubject'}|$date|$awards{'imtext'}|$messageid|0|$ENV{'REMOTE_ADDR'}|s|u||";
        $awards_imtext =~ s/{award}/$awards{'title'}/gxsm;
        $awards_imtext =~ s/{reason}/$award_reason/gxsm;
        $awards_imtext =~ s/{name}/${ $uid . $user }{'realname'}/gxsm;
        $awards_imtext =~ s/{myname}/${ $uid . $username }{'realname'}/gxsm;
        $awards_imtext =~ s/{mbname}/$mbname/gxsm;
        our ($INBOX);

        fopen( 'INBOX', '<', "$memberdir/$user.msg" );
        my @inmessages = <$INBOX>;
        fclose('INBOX');
        unshift @inmessages, $awardmess;
        fopen( 'INBOX', '>', "$memberdir/$user.msg" );
        print {$INBOX} @inmessages;
        fclose('INBOX');
        update_ims( $user, $messageid, 'messagein' );
    }

    $yysetlocation =
      qq~$scripturl?action=viewprofile;username=$useraccount{$user}~;
    redirectexit();
}

sub AwardEdit {
    if ( !$iamadmin && ( !$iamgmod || !$en_awards_gmod ) ) {
        fatal_error('not_allowed');
    }
    my $user = $INFO{'username'};
    if ( !load_user($user) ) { fatal_error('no_profile_exists'); }

    my $id          = $INFO{'id'};
    my $show_awards = q{};

    our ($UAWARDS);
    fopen( 'UAWARDS', '<', "$memberdir/$user.awards" );
    my @getawards = <$UAWARDS>;
    fclose('UAWARDS');

    our (%award_list);
    require "Languages/English/Mods/Awards.txt";
    our (%awards);
    load_language('Mods/Awards_set');
    for my $award (keys %award_list) {
        if ( $award =~ /\b$id\b/ ) {
            $award_title = ${$award_list{$award}}[1];
        }
    }
    my ( $user_award_date, $user_award_id, $user_award_reason,
        $user_award_who );
    for my $award (keys %award_list) {
        chomp $award;
        my ( $award_id, $award_title, $award_image, $award_desc ) = @{$award_list{$award}};
         my $sel_award  = q{};
        my $award_edit = q{};
        for my $user_award (@getawards) {
            chomp $user_award;
            if ( $user_award =~ /\b$id\b/ ) {
                $award_edit = $user_award;
                last;
            }
        }
        (
            $user_award_date,   $user_award_id,
            $user_award_reason, $user_award_who
        ) = split /[|]/xsm, $award_edit;
        if ( $user_award_id eq $award_id ) {
            $sel_award = qq~ selected="selected"~;
        }
        $show_awards .=
          qq~<option value="$award_id"$sel_award>$award_title</option>\n~;
    }
    $yymain = $tem_award_edit;
    $yymain =~ s/\Q{yabb awards_name}\E/$awards{'name'}/gxsm;
    {
        no strict qw(refs);
        $yymain =~ s/\Q{yabb id}\E/${$uid.$user}{'realname'}/gxsm;
    }
    $yymain =~ s/\Q{yabb show_awards}\E/$show_awards/gxsm;
    $yymain =~ s/\Q{yabb username}\E/$useraccount{$user}/gxsm;
    $yymain =~ s/\Q{yabb show_awards}\E/$show_awards/gxsm;
    $yymain =~ s/\Q{yabb show_reason}\E/$user_award_reason/gxsm;
    $yymain =~ s/\Q{user_award_date}\E/$user_award_date/gxsm;
    $yymain =~ s/\Q{award_who}\E/$user_award_who/gxsm;

    {
        no strict qw(refs);
        $yytitle = "$awards_name - ${ $uid . $user }{'realname'}";
    }
    $yynavigation = qq~&rsaquo; $awards_name~;
    template();

}

sub AwardEdit2 {

    if ( !$iamadmin && ( !$iamgmod || !$en_awards_gmod ) ) {
        fatal_error('not_allowed');
    }

    $user = $FORM{'username'};
    if ( !load_user($user) ) { fatal_error('no_profile_exists'); }

    my $award_id     = $FORM{'award'};
    my $award_reason = $FORM{'award_reason'};
    my $award_date   = $FORM{'award_date'};
    my $award_who    = $FORM{'award_who'};

    if ( !$FORM{'award'} )        { fatal_error('no_award'); }
    if ( !$FORM{'award_reason'} ) { fatal_error('no_award_reason'); }

    our ($AWARDS);
    fopen( 'AWARDS', '<', "$memberdir/$user.awards" )
      || fatal_error( 'cannot_open', "$memberdir/$user.awards", 1 );
    my @awards = <AWARDS>;
    fclose('AWARDS');

    my @award = grep ( !/$award_date/, @awards );
    push( @award, "$award_date|$award_id|$award_reason|$award_who" );
    my $award = join( q{}, @award );

    fopen( 'AWARDS', '>', "$memberdir/$user.awards" )
      || fatal_error( 'cannot_open', "$memberdir/$user.awards", 1 );
    print {$AWARDS} "$award\n";
    fclose('AWARDS');

    $yysetlocation =
      qq~$scripturl?action=viewprofile;username=$useraccount{$user}~;
    redirectexit();
}

sub AwardDelete {

    if ( !$iamadmin && ( !$iamgmod || !$en_awards_gmod ) ) {
        fatal_error('not_allowed');
    }

    $user = $INFO{'username'};
    if ( !load_user($user) ) { fatal_error('no_profile_exists'); }

    our ($AWARDS);
    fopen( 'AWARDS', '<', "$memberdir/$user.awards" )
      || fatal_error( 'cannot_open', "$memberdir/$user.awards", 1 );
    my @awards = <$AWARDS>;
    fclose('AWARDS');

    fopen( 'AWARDS', '>', "$memberdir/$user.awards" )
      || fatal_error( 'cannot_open', "$memberdir/$user.awards", 1 );
    print {$AWARDS} grep ( !/$INFO{'id'}/, @awards );
    fclose('AWARDS');

    $yysetlocation =
      qq~$scripturl?action=viewprofile;username=$useraccount{$user}~;
    redirectexit();
}

1;
